@@ -7,9 +7,9 @@ fn base() {
     assert!(CELL.set(1).is_ok());
     assert!(CELL.is_initialized());
     assert!(CELL.set(2).is_err());
-    assert_eq!(CELL.take().unwrap(), 1);
+    assert_eq!(CELL.take().unwrap(), Some(1));
     assert!(!CELL.is_initialized());
-    assert!(CELL.take().is_none());
+    assert!(CELL.take().unwrap().is_none());
 
     assert!(CELL.ref_num().is_err());
     assert!(CELL.set(3).is_ok());
@@ -17,19 +17,19 @@ fn base() {
     let refer = CELL.get().unwrap();
     assert_eq!(CELL.ref_num(), Ok(1));
     assert_eq!(*refer, 3);
-    assert!(CELL.take().is_none());
+    assert!(CELL.take().unwrap().is_none());
     drop(refer);
-    assert_eq!(CELL.take().unwrap(), 3);
+    assert_eq!(CELL.take().unwrap(), Some(3));
 
     assert!(CELL.set(4).is_ok());
     assert_eq!(*CELL.get().unwrap(), 4);
-    assert_eq!(CELL.take().unwrap(), 4);
+    assert_eq!(CELL.take().unwrap(), Some(4));
 
-    assert_eq!(CELL.swap(5), Ok(None));
-    assert_eq!(CELL.swap(6), Ok(Some(5)));
+    assert_eq!(CELL.replace(5), Ok(None));
+    assert_eq!(CELL.replace(6), Ok(Some(5)));
     let refer = CELL.get();
-    assert_eq!(CELL.swap(7), Err(7));
+    assert_eq!(CELL.replace(7), Err(7));
     drop(refer);
-    assert_eq!(CELL.swap(8), Ok(Some(6)));
-    assert_eq!(CELL.take().unwrap(), 8);
+    assert_eq!(CELL.replace(8), Ok(Some(6)));
+    assert_eq!(CELL.take().unwrap(), Some(8));
 }
