@@ -25,7 +25,7 @@ fn test() {
     let h = thread::spawn(move || {
         for _ in TEST_DATA {
             loop {
-                let result = CELL.take();
+                let result = CELL.take().unwrap();
                 if let Some(i) = result {
                     assert!(data_set.remove(&i));
                     break;
